@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/qtooltip.h   3.3.4   edited May 27 2003 $
+** $Id: qt/qtooltip.h   3.3.7   edited Jan 30 2006 $
 **
 ** Definition of Tool Tips (or Balloon Help) for any widget or rectangle
 **
-** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the widgets module of the Qt GUI Toolkit.
 **
@@ -42,6 +42,9 @@
 
 #ifndef QT_NO_TOOLTIP
 
+#if __GNUC__  - 0 > 3
+#pragma GCC system_header
+#endif
 
 class QTipManager;
 class QIconViewToolTip;
