@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/msvc_objectmodel.cpp   3.3.3   edited Jul 27 19:17 $
+** $Id: qt/msvc_objectmodel.cpp   3.3.7   edited Feb 7 2006 $
 **
 ** Implementation of VCProject class.
 **
-** Copyright (C) 2002-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 2002-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of qmake.
 **
@@ -165,6 +165,7 @@ const char* _Name4				= "\n\t\t\t\tName=\"";
 const char* _Name5				= "\n\t\t\t\t\tName=\"";
 const char* _ObjectFile 			= "\n\t\t\t\tObjectFile=\"";
 const char* _OmitFramePointers 			= "\n\t\t\t\tOmitFramePointers=\"";
+const char* _OpenMP                             = "\n\t\t\t\tOpenMP=\"";
 const char* _Optimization 			= "\n\t\t\t\tOptimization =\"";
 const char* _OptimizeForProcessor 		= "\n\t\t\t\tOptimizeForProcessor=\"";
 const char* _OptimizeForWindows98 		= "\n\t\t\t\tOptimizeForWindows98=\"";
@@ -345,6 +346,7 @@ VCCLCompilerTool::VCCLCompilerTool()
 	KeepComments( unset ),
 	MinimalRebuild( unset ),
 	OmitFramePointers( unset ),
+	OpenMP( unset ),
 	Optimization( optimizeCustom ),
 	OptimizeForProcessor( procOptimizeBlended ),
 	OptimizeForWindowsApplication( unset ),
@@ -416,6 +418,7 @@ QTextStream &operator<<( QTextStream &strm, const VCCLCompilerTool &tool )
     if ( !tool.ProgramDataBaseFileName.isNull() ) strm << _ProgramDataBaseFileName << tool.ProgramDataBaseFileName.latin1() << "\"";
     if ( tool.RuntimeLibrary != rtUnknown ) strm << EPair( _RuntimeLibrary, tool.RuntimeLibrary );
     strm << TPair( _RuntimeTypeInfo, tool.RuntimeTypeInfo );
+    strm << TPair( _OpenMP, tool.OpenMP );
     strm << TPair( _ShowIncludes, tool.ShowIncludes );
     strm << TPair( _SmallerTypeCheck, tool.SmallerTypeCheck );
     strm << TPair( _StringPooling, tool.StringPooling );
@@ -908,6 +911,12 @@ bool VCCLCompilerTool::parseOption( const char* option )
 	    break;
 	}
 	found = FALSE; break;
+    case 'o':
+        if ( second == 'p' && third == 'e' && fourth == 'n' ) {
+            OpenMP = _True;
+            break;
+        }
+	found = FALSE; break;
     case 's':
 	if ( second == 'h' && third == 'o' && fourth == 'w' ) {
 	    ShowIncludes = _True;
@@ -1974,10 +1983,27 @@ bool VCFilter::addIMGstage( QTextStream &/*strm*/, QString str )
     }
 
     QString uicApp = Project->var("QMAKE_UIC");
-    CustomBuildTool.Description = ("Generate imagecollection");
-    CustomBuildTool.CommandLine +=
-	uicApp + " -embed " + Project->project->first("QMAKE_ORIG_TARGET")
+    QString commandLine = uicApp + " -embed " + Project->project->first("QMAKE_ORIG_TARGET")
 	+ " -f .imgcol -o " + collectionName;
+
+    // The loop below is to avoid the resulting CommandLine buffer
+    // from being a size of between 2071-#char_replaced and 2102,
+    // as this triggers a buffer overflow bug in VS2003. As we only
+    // the only replacement we use in this buffer is one $(QTDIR),
+    // we assume this can be upto 256 characters long, making the
+    // lower-bound to be 1814 characters. So, if the buffer is
+    // between 1814 and 2103 bytes, the buffer is "padded" til it's
+    // over 2103 bytes in size.
+    int totalSize = CustomBuildTool.CommandLine.join("  ").length();
+    while (totalSize > 1814 && totalSize < 2103) {
+        CustomBuildTool.CommandLine += 
+            "echo \"Padding\" the Custom Build Step buffer to avoid a potentional "
+            "buffer overflow issue with VS2003 for buffer of 1814-2103 bytes > nul";
+        totalSize = CustomBuildTool.CommandLine.join("  ").length();
+    }
+
+    CustomBuildTool.Description = ("Generate imagecollection");
+    CustomBuildTool.CommandLine += commandLine;
     CustomBuildTool.AdditionalDependencies += uicApp;
     CustomBuildTool.AdditionalDependencies += list;
     CustomBuildTool.Outputs = collectionName;
