@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qfontengine_x11.cpp   3.3.6   edited Feb 13 13:35 $
+** $Id: qt/qfontengine_x11.cpp   3.3.7   edited Oct 19 14:53 $
 **
 ** ???
 **
@@ -171,7 +171,8 @@ static void drawScaled(int x, int y, const QTextEngine *engine, const QScriptIte
 
     QRect br = xmat.mapRect(QRect(x, y - si->ascent, w, h));
     QRect br2 = br & pdevRect;
-    if (br2.width() <= 0 || br2.height() <= 0)
+    if (br2.width() <= 0 || br2.height() <= 0
+        || br2.width() >= 32768 || br2.height() >= 32768)
         return;
     QWMatrix mat = QPixmap::trueMatrix( xmat, w, h );
     QBitmap wx_bm = ::transform(dpy, bm, br2.x() - br.x(), br2.y() - br.y(), br2.width(), br2.height(), mat);
