@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qucomextra_p.h   3.3.2   edited May 27 2003 $
+** $Id: qt/qucomextra_p.h   3.3.7   edited Jan 30 2006 $
 **
 ** Definition of extra QUcom classes
 **
 ** Created : 990101
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -54,6 +54,9 @@
 #include <private/qucom_p.h>
 #endif // QT_H
 
+#if __GNUC__ - 0 > 3
+#pragma GCC system_header
+#endif
 
 class QVariant;
 
