@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qglobal.cpp   3.3.4   edited Jan 5 12:10 $
+** $Id: qt/qglobal.cpp   3.3.7   edited Feb 22 2006 $
 **
 ** Global functions
 **
 ** Created : 920604
 **
-** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the tools module of the Qt GUI Toolkit.
 **
@@ -221,7 +221,9 @@ int qMacVersion()
 	first = FALSE;
 	long gestalt_version;
 	if(Gestalt(gestaltSystemVersion, &gestalt_version) == noErr) {
-	    if(gestalt_version >= 0x1030 && gestalt_version < 0x1040)
+            if(gestalt_version >= 0x1040 && gestalt_version < 0x1050)
+		macver = Qt::MV_10_DOT_4;
+	    else if(gestalt_version >= 0x1030 && gestalt_version < 0x1040)
 		macver = Qt::MV_10_DOT_3;
 	    else if(gestalt_version >= 0x1020 && gestalt_version < 0x1030)
 		macver = Qt::MV_10_DOT_2;
@@ -316,6 +318,8 @@ int qWinVersion()
 	default: // VER_PLATFORM_WIN32_NT
 	    if ( osver.dwMajorVersion < 5 ) {
 		winver = Qt::WV_NT;
+	    } else if (osver.dwMajorVersion == 6) {
+	    winver = Qt::WV_VISTA;
 	    } else if ( osver.dwMinorVersion == 0 ) {
 		winver = Qt::WV_2000;
 	    } else if ( osver.dwMinorVersion == 1 ) {
