@@ -1,9 +1,9 @@
 /****************************************************************************
-** $Id: qt/qmutexpool_p.h   3.2.1   edited May 13 09:08 $
+** $Id: qt/qmutexpool_p.h   3.3.7   edited Aug 31 2005 $
 **
 ** ...
 **
-** Copyright (C) 2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the tools module of the Qt GUI Toolkit.
 **
@@ -50,10 +50,12 @@
 
 #ifdef QT_THREAD_SUPPORT
 
+#ifndef QT_H
 #include "qmutex.h"
 #include "qmemarray.h"
+#endif // QT_H
 
-class QMutexPool
+class Q_EXPORT QMutexPool
 {
 public:
     QMutexPool( bool recursive = FALSE, int size = 17 );
@@ -68,7 +70,7 @@ private:
     bool recurs;
 };
 
-extern QMutexPool *qt_global_mutexpool;
+extern Q_EXPORT QMutexPool *qt_global_mutexpool;
 
 #endif // QT_THREAD_SUPPORT
 
