@@ -1,5 +1,5 @@
 /**********************************************************************
-** $Id: qt/qlineedit.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/qlineedit.cpp   3.3.7   edited Feb 15 2006 $
 **
 ** Implementation of QLineEdit widget class
 **
@@ -1794,8 +1794,9 @@ void QLineEdit::imComposeEvent( QIMEvent *e )
     d->imend = d->imstart + e->text().length();
     d->imselstart = d->imstart + e->cursorPos();
     d->imselend = d->imselstart + e->selectionLength();
-    d->cursor = e->selectionLength() ? d->imend : d->imselend;
+    d->cursor = d->imstart + e->cursorPos();
     d->updateTextLayout();
+    d->updateMicroFocusHint();
     update();
 }
 
@@ -1978,6 +1979,7 @@ void QLineEdit::drawContents( QPainter *p )
 	    p->setPen( paletteBackgroundColor() );
 	    p->drawTextItem( topLeft, ti, textflags );
 	    p->restore();
+            supressCursor = TRUE;
 	}
 
 	// overwrite cursor
