@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qmenubar.cpp   3.3.4   edited Jan 26 2004 $
+** $Id: qt/qmenubar.cpp   3.3.7   edited Jan 27 2006 $
 **
 ** Implementation of QMenuBar class
 **
 ** Created : 941209
 **
-** Copyright (C) 1992-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the widgets module of the Qt GUI Toolkit.
 **
@@ -482,7 +482,7 @@ void QMenuBar::frameChanged()
 
 void QMenuBar::languageChange()
 {
-    menuContentsChanged(); 
+    menuContentsChanged();
 }
 
 /*!
@@ -909,6 +909,8 @@ int QMenuBar::calculateRects( int max_width )
     if ( gs == MotifStyle ) {
 	x += motifBarHMargin;
 	y += motifBarVMargin;
+    } else if ( style().inherits("QWindowsXPStyle") && style().styleHint(QStyle::SH_TitleBar_NoBorder) ) {
+        ;
     } else if ( gs == WindowsStyle ) {
 	x += 2;
 	y += 2;
@@ -958,7 +960,7 @@ int QMenuBar::calculateRects( int max_width )
 #if defined(Q_WS_MAC) && !defined(QMAC_QMENUBAR_NO_NATIVE)
 	    if ( !mac_eaten_menubar ) {
 #endif
-		if ( gs == MotifStyle ) {
+		if ( gs == MotifStyle && mi->isVisible() ) {
 		    w += 2*motifItemFrame;
 		    h += 2*motifItemFrame;
 		}
