@@ -1,5 +1,5 @@
 /**********************************************************************
-** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the Qt Assistant.
 **
@@ -30,6 +30,8 @@
 #include "helpdialogimpl.h"
 #include "config.h"
 
+#include <qapplication.h>
+#include <qclipboard.h>
 #include <qurl.h>
 #include <qmessagebox.h>
 #include <qdir.h>
@@ -47,9 +49,11 @@
 #endif
 
 HelpWindow::HelpWindow( MainWindow *w, QWidget *parent, const char *name )
-    : QTextBrowser( parent, name ), mw( w ), shiftPressed( FALSE ), blockScroll( FALSE )
+    : QTextBrowser( parent, name ), mw( w ), blockScroll( FALSE ),
+      shiftPressed( FALSE ), newWindow( FALSE )
 {
-
+    connect(this, SIGNAL(forwardAvailable(bool)), this, SLOT(updateForward(bool)));
+    connect(this, SIGNAL(backwardAvailable(bool)), this, SLOT(updateBackward(bool)));
 }
 
 void HelpWindow::setSource( const QString &name )
@@ -57,7 +61,7 @@ void HelpWindow::setSource( const QString &name )
     if ( name.isEmpty() )
 	return;
 
-    if ( shiftPressed ) {
+    if (newWindow || shiftPressed) {
 	removeSelection();
 	mw->saveSettings();
 	mw->saveToolbarSettings();
@@ -69,14 +73,14 @@ void HelpWindow::setSource( const QString &name )
 	if( linkInfo.isRelative() )
 	    target = currentInfo.dirPath( TRUE ) + "/" + name;
 
-	nmw->setup();
-	nmw->showLink( target );
+	nmw->setup();	
 	nmw->move( mw->geometry().topLeft() );
 	if ( mw->isMaximized() )
 	    nmw->showMaximized();
 	else
 	    nmw->show();
-	return;
+    nmw->showLink( target );
+    return;
     }
 
     if ( name.left( 7 ) == "http://" || name.left( 6 ) == "ftp://" ) {
@@ -88,6 +92,8 @@ void HelpWindow::setSource( const QString &name )
 	    } , {
 		ShellExecuteA( winId(), 0, name.local8Bit(), 0, 0, SW_SHOWNORMAL );
 	    } );
+#elif defined(Q_OS_MACX)
+	    webbrowser = "/usr/bin/open";
 #else
 	    int result = QMessageBox::information( mw, tr( "Help" ),
 			 tr( "Currently no Web browser is selected.\nPlease use the settings dialog to specify one!\n" ),
@@ -100,21 +106,27 @@ void HelpWindow::setSource( const QString &name )
 	    if ( webbrowser.isEmpty() )
 		return;
 	}
-	QProcess *proc = new QProcess();
+	QProcess *proc = new QProcess(this);
+
 	proc->addArgument( webbrowser );
+        QObject::connect(proc, SIGNAL(processExited()), proc, SLOT(deleteLater()));
 	proc->addArgument( name );
-	proc->launch( "" );
+	proc->start();
 	return;
     }
 
     if ( name.right( 3 ) == "pdf" ) {
 	QString pdfbrowser = Config::configuration()->pdfReader();
 	if ( pdfbrowser.isEmpty() ) {
+#if defined(Q_OS_MACX)
+	    pdfbrowser = "/usr/bin/open";
+#else
 	    QMessageBox::information( mw,
 				      tr( "Help" ),
 				      tr( "No PDF Viewer has been specified\n"
 					  "Please use the settings dialog to specify one!\n" ) );
 	    return;
+#endif
 	}
 	QFileInfo info( pdfbrowser );
 	if( !info.exists() ) {
@@ -126,10 +138,11 @@ void HelpWindow::setSource( const QString &name )
 					  "the specified location." ).arg( pdfbrowser ) );
 	    return;
 	}
-	QProcess *proc = new QProcess();
+	QProcess *proc = new QProcess(this);
+        QObject::connect(proc, SIGNAL(processExited()), proc, SLOT(deleteLater()));
 	proc->addArgument( pdfbrowser );
 	proc->addArgument( name );
-	proc->launch( "" );
+	proc->start();
 
 	return;
     }
@@ -141,18 +154,8 @@ void HelpWindow::setSource( const QString &name )
 	return;
     }
 
-    int i = name.find( '#' );
-    QString sect = name;
-    if ( i != -1 )
-	sect = name.left( i );
-
-    setCharacterEncoding( sect );
+    setText("<body bgcolor=\"" + paletteBackgroundColor().name() + "\">");
     QTextBrowser::setSource( name );
-
-    if( !documentTitle().isEmpty() )
-	mw->browsers()->updateTitle( documentTitle() );
-    else
-	mw->browsers()->updateTitle( tr( "Untitled" ) );
 }
 
 
@@ -160,10 +163,9 @@ void HelpWindow::openLinkInNewWindow()
 {
     if ( lastAnchor.isEmpty() )
 	return;
-    bool oldShiftPressed = shiftPressed;
-    shiftPressed = TRUE;
-    setSource( lastAnchor );
-    shiftPressed = oldShiftPressed;
+    newWindow = TRUE;
+    setSource(lastAnchor);
+    newWindow = FALSE;
 }
 
 void HelpWindow::openLinkInNewWindow( const QString &link )
@@ -198,7 +200,7 @@ QPopupMenu *HelpWindow::createPopupMenu( const QPoint& pos )
 	}
 	m->insertItem( tr("Open Link in New Window\tShift+LMB"),
 		       this, SLOT( openLinkInNewWindow() ) );
-	m->insertItem( tr("Open Link in New Page"),
+	m->insertItem( tr("Open Link in New Tab"),
 		       this, SLOT( openLinkInNewPage() ) );
     }
     mw->actionNewWindow->addTo( m );
@@ -217,18 +219,6 @@ QPopupMenu *HelpWindow::createPopupMenu( const QPoint& pos )
     return m;
 }
 
-void HelpWindow::keyPressEvent( QKeyEvent *e )
-{
-    shiftPressed = e->key() == Key_Shift   ? TRUE : shiftPressed;
-    QTextBrowser::keyPressEvent( e );
-}
-
-void HelpWindow::keyReleaseEvent( QKeyEvent *e )
-{
-    shiftPressed = e->key() == Key_Shift   ? FALSE : shiftPressed;
-    QTextBrowser::keyReleaseEvent( e );
-}
-
 void HelpWindow::blockScrolling( bool b )
 {
     blockScroll = b;
@@ -240,34 +230,46 @@ void HelpWindow::ensureCursorVisible()
 	QTextBrowser::ensureCursorVisible();
 }
 
-void HelpWindow::setCharacterEncoding( const QString &name )
+void HelpWindow::contentsMousePressEvent(QMouseEvent *e)
 {
-    QFile file( name );
-    if ( !file.open( IO_ReadOnly ) ) {
-	qWarning( "can not open file " + name );
-	return;
+    shiftPressed = ( e->state() & ShiftButton );
+    QTextBrowser::contentsMousePressEvent(e);
+}
+
+void HelpWindow::keyPressEvent(QKeyEvent *e)
+{
+    shiftPressed = ( e->state() & ShiftButton );
+    QTextBrowser::keyPressEvent(e);
+}
+
+void HelpWindow::copy()
+{
+    if (textFormat() == PlainText) {
+	QTextEdit::copy();
+    } else {
+	TextFormat oldTf = textFormat();
+	setTextFormat(PlainText);
+	QString selectText = selectedText();
+	selectText.replace("<br>", "\n");
+	selectText.replace("\xa0", " ");
+	selectText.replace("&gt;", ">");
+	selectText.replace("&lt;", "<");
+	selectText.replace("&amp;", "&");
+
+	QClipboard *cb = QApplication::clipboard();
+	if (cb->supportsSelection())
+	    cb->setText(selectText, QClipboard::Selection);
+	cb->setText(selectText, QClipboard::Clipboard);
+	setTextFormat(oldTf);
     }
+}
 
-    QTextStream s( &file );
-    s.setEncoding( QTextStream::Latin1 );
+void HelpWindow::updateForward(bool fwd)
+{
+    fwdAvail = fwd;
+}
 
-    QString text;
-    while ( !s.atEnd() ) {
-	text += s.readLine().lower();
-	if ( text.contains( "</head>", FALSE ) )
-	    break;
-    }
-    int i = text.find( "charset=" );
-    QString encoding;
-    if ( i > -1 ) {
-	encoding = text.right( text.length() - (i+8) );
-	encoding = encoding.left( encoding.find( "\"" ) );
-    }
-    QTextCodec *codec = QTextCodec::codecForName( encoding.latin1() );
-    if ( !codec )
-	encoding = "utf-8";
-    else
-	encoding = QString( codec->name() );
-    QString extension = QString( "text/html; charset=%1" ).arg( encoding );
-    mw->browsers()->setMimeExtension( extension );
+void HelpWindow::updateBackward(bool back)
+{
+    backAvail = back;
 }
