@@ -1,4 +1,4 @@
-(defvar designer-exec "/home/joe/qt/bin/designer")
+(defvar designer-exec (concat (getenv "QTDIR") "/bin/designer"))
 
 (defun designer-open-ui-file ()
   (interactive)
@@ -9,11 +9,11 @@
 (defun designer-create-ui-file (&optional arg)
   (interactive "FNew UI-File: ")
   (find-file arg)
-  (insert " ")
+  (insert "<UI></UI>")
   (save-buffer)
   (designer-open-ui-file)
 )
 
-(global-set-key [f7] 'designer-open-ui-file)
-(global-set-key [f8] 'designer-create-ui-file)
+;(global-set-key [f7] 'designer-open-ui-file)
+;(global-set-key [f8] 'designer-create-ui-file)
 
