@@ -539,8 +539,6 @@ void MessageEditor::toggleFinished()
 
 bool MessageEditor::eventFilter( QObject *o, QEvent *e )
 {
-    static uchar doFocusChange = FALSE;
-
     // Handle keypresses in the message editor - scroll the view if the current
     // line is hidden.
     if ( e->type() == QEvent::KeyPress || e->type() == QEvent::KeyRelease ) {
@@ -551,17 +549,10 @@ bool MessageEditor::eventFilter( QObject *o, QEvent *e )
 	    if ( e->type() == QEvent::KeyPress ) {
 		// Hardcode the Tab key to do focus changes when pressed
 		// inside the editor
-		if ( doFocusChange ) {
-		    if ( k == Key_BackTab ) {
-			emit focusSourceList();
-			doFocusChange = FALSE;
-			return TRUE;
-		    } else if ( k == Key_Tab ) {
-			emit focusPhraseList();
-			doFocusChange = FALSE;
-			return TRUE;
-		    }
-		}
+                if ( k == Key_BackTab ) {
+                    emit focusSourceList();
+                    return TRUE;
+                }
 	    } else if ( e->type() == QEvent::KeyRelease ) {
 		MED * ed = (MED *) o;
 		switch( k ) {
@@ -590,7 +581,6 @@ bool MessageEditor::eventFilter( QObject *o, QEvent *e )
 		    break;
 		}
 	    }
-	    doFocusChange = TRUE;
 	} else if ( ::qt_cast<QListView*>(o) ) {
 	    // handle the ESC key in the list views
 	    if ( e->type() == QEvent::KeyRelease && k == Key_Escape )
