@@ -1,5 +1,5 @@
 /**********************************************************************
-** Copyright (C) 2000-2002 Trolltech AS.  All rights reserved.
+** Copyright (C) 2000-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of Qt Linguist.
 **
@@ -770,7 +770,7 @@ void TrWindow::openPhraseBook()
 	tr("Open Phrase Book") );
     if ( !name.isEmpty() && !phraseBookNames.contains(name) ) {
 	if ( openPhraseBook(name) ) {
-	    int n = phraseBooks.at( phraseBooks.count() - 1 )->count();
+	    int n = (int)(phraseBooks.at( phraseBooks.count() - 1 )->count());
 	    statusBar()->message( tr("%1 phrase(s) loaded.").arg(n),
 				  MessageMS );
 	}
